@@ -26,6 +26,9 @@
 #' @import stats
 #' @import checkmate
 #' @import optimr
+#' @import Formula
+#' @importFrom sandwich estfun
+#' @importFrom lmtest coeftest coefci
 #'
 #' @docType package
 #' @name aldvmm-package
@@ -48,8 +51,7 @@ NULL
 #'   model for expected values of normal distributions (left) and the
 #'   multinomial logit model of probabilities of component membership (right).
 #' @param data a data frame, list or environment (or object coercible to a data
-#'   frame by \cr \ifelse{html}{\code{\link[base]{as.data.frame}}}{
-#'   \code{base::as.data.frame()}}) including data on outcomes and explanatory
+#'   frame by \ifelse{html}{\code{\link[base]{as.data.frame}}}{\code{base::as.data.frame()}}) including data on outcomes and explanatory
 #'   variables in \code{'formula'}.
 #' @param psi a numeric vector of minimum and maximum possible utility values
 #'   smaller than or equal to 1 (e.g. \code{c(-0.594, 0.883)}). The potential
@@ -70,7 +72,7 @@ NULL
 #'   \ifelse{html}{\code{\link[optimr]{optimr}}}{\code{optimr::optimr()}}
 #'   methods: \code{"Nelder-Mead"}, \code{"BFGS"}, \code{"CG"},
 #'   \code{"L-BFGS-B"}, \code{"nlminb"}, \code{"Rcgmin"}, \code{"Rvmmin"} and
-#'   \code{"hjn"}. The default method is \code{"Nelder-Mead"}. The method
+#'   \code{"hjn"}. The default method is \code{"BFGS"}. The method
 #'   \code{"L-BFGS-B"} is used when lower and/or upper constraints are set
 #'   using \code{'init.lo'} and \code{'init.hi'}. The method \code{"nlm"}
 #'   cannot be used in the \code{'aldvmm'} package.
@@ -99,8 +101,15 @@ NULL
 #'   \code{'par'}.
 #' @param se.fit an optional logical value indicating whether standard errors
 #'   of fitted values are calculated. The default value is \code{FALSE}.
+#' @param model an optional logical value indicating whether the estimation 
+#' data frame is returned in the output object. The default value is \code{TRUE}.
 #' @param level a numeric value of the significance level for confidence bands
 #'   of fitted values. The default value is 0.95.
+#' @param na.action a character value indicating the argument passed to 
+#' argument \code{'na.action'} of the function 
+#' \ifelse{html}{\code{\link[stats]{model.frame}}}{\code{stats::model.frame()}} 
+#' in the preparation of the model matrix. The default value is 
+#' \code{"na.omit"}.
 #'
 #' @details \ifelse{html}{\code{\link[aldvmm]{aldvmm}}}{ \code{aldvmm()}} fits
 #'   an adjusted limited dependent variable mixture model using the likelihood
@@ -135,7 +144,7 @@ NULL
 #'   \code{'optim.method'} accepts the following methods: \code{"Nelder-Mead"},
 #'   \code{"BFGS"}, \code{"CG"}, \code{"L-BFGS-B"}, \code{"nlminb"},
 #'   \code{"Rcgmin"}, \code{"Rvmmin"} and \code{"hjn"}. The default method is
-#'   \code{"Nelder-Mead"}.  The method \code{"nlm"} cannot be used in
+#'   \code{"BFGS"}.  The method \code{"nlm"} cannot be used in
 #'   \ifelse{html}{\code{\link[aldvmm]{aldvmm}}}{ \code{aldvmm()}} because it
 #'   requires a different implementation of the likelihood function. The
 #'   argument \code{'optim.control'} accepts a list of
@@ -159,7 +168,7 @@ NULL
 #'   method \code{"random"} draws random starting values from a standard normal
 #'   distribution.  The method \code{"constant"} estimates a constant-only
 #'   model and uses estimates as initial values of intercepts and standard
-#'   errors and 0 for all other prameters.  The method \code{"sann"} estimates
+#'   errors and 0 for all other parameters.  The method \code{"sann"} estimates
 #'   the full model using the simulated annealing optimization method in
 #'   \ifelse{html}{\code{\link[stats]{optim}}}{ \code{stats::optim()}} and uses
 #'   parameter estimates as initial values.  When user-specified initial values
@@ -190,26 +199,28 @@ NULL
 #' @return \ifelse{html}{\code{\link[aldvmm]{aldvmm}}}{ \code{aldvmm()}}
 #'   returns an object of class inheriting from "aldvmm". An object of class
 #'   "aldvmm" is a list containing the following objects. \item{\code{coef}}{a
-#'   numeric vector of parameter estimates.} \item{\code{se}}{a numeric vector
-#'   of standard errors of parameter estimates.} \item{\code{z}}{a numeric
-#'   vector of standardized parameter estimates.} \item{\code{p}}{a numeric
-#'   vector of p-values of parameter estimates.} \item{\code{lower}}{a numeric
-#'   vector of 95\% lower confidence limits of parameter estimates.}
-#'   \item{\code{upper}}{a numeric vector of 95\% upper confidence limits of
-#'   parameter estimates.} \item{\code{hessian}}{a numeric matrix object with
+#'   numeric vector of parameter estimates.} \item{\code{hessian}}{a numeric matrix object with
 #'   second partial derivatives of the likelihood function.}
 #'
 #'   \item{\code{cov}}{a numeric matrix object with covariances of parameters.}
 #'
 #'   \item{\code{n}}{a scalar representing the number of complete observations
 #'   with no missing values that were used in the estimation.}
-#'
 #'   \item{\code{k}}{a scalar representing the number of components that were
 #'   mixed.}
-#'
+#'   \item{\code{df.null}}{an integer value of the residual 
+#'   degrees of freedom of a null model including intercepts and standard errors.}
+#'   \item{\code{df.residual}}{an integer value of the residual 
+#'   degrees of freedom..}
+#'   \item{\code{iter}}{an integer value of the number of iterations used in 
+#'   optimization.}
+#'   \item{\code{convergence}}{an integer value indicating convergence. "0" 
+#'   indicates successful completion.}
+#'   
 #'   \item{\code{gof}}{a list including the following elements. \describe{
 #'   \item{\code{ll}}{a numeric value of the negative log-likelihood
-#'   \eqn{-ll}.} \item{\code{aic}}{a numeric value of the Akaike information
+#'   \eqn{-ll}.} 
+#'   \item{\code{aic}}{a numeric value of the Akaike information
 #'   criterion \eqn{AIC = 2n_{par} - 2ll}{AIC = 2*npar - 2*ll}.}
 #'   \item{\code{bic}}{a numeric value of the Bayesian information criterion
 #'   \eqn{BIC = n_{par}*log(n_{obs}) - 2ll}{BIC = npar*log(nobs) - 2*ll}.}
@@ -234,10 +245,20 @@ NULL
 #'   \item{\code{hi}}{a numeric vector of upper limits of parameter
 #'   estimates.}} }
 #'
+#'   \item{\code{call}}{a character value including the model call captured by
+#'   \ifelse{html}{\code{\link[base]{match.call}}}{\code{base::match.call}}.}
 #'   \item{\code{formula}}{an object of class
 #'   \ifelse{html}{\code{\link[stats]{formula}}}{\code{stats::formula}}
 #'   supplied to argument \code{'formula'}.}
+#'   \item{\code{terms}}{a list of objects of class
+#'   \ifelse{html}{\code{\link[stats]{terms}}}{\code{stats::terms}} for the model of component means ("beta"), probabilities of component membership ("delta") and the full model ("full").}
+#'   \item{\code{contrasts}}{a nested list of character values showing 
+#'   contrasts of factors used in models of component means ("beta") and 
+#'   probabilities of component membership ("delta").}
 #'
+#'   \item{\code{data}}{a data frame created by 
+#'   \ifelse{html}{\code{\link[stats]{model.frame}}}{\code{stats::model.frame}} 
+#'   including estimation data with additional attributes.}
 #'   \item{\code{psi}}{a numeric vector with the minimum and maximum utility
 #'   below 1 in \code{'data'}.}
 #'
@@ -258,6 +279,12 @@ NULL
 #'   \item{\code{optim.method}}{a character value of the used
 #'   \ifelse{html}{\code{\link[optimr]{optimr}}}{\code{optimr::optimr()}}
 #'   method.}
+#'   \item{\code{level}}{a numeric value of the confidence level used for 
+#'   reporting.}
+#'   \item{\code{na.action}}{an object of class "omit" extracted from the 
+#'   "na.action" attribute of the data frame created by 
+#'   \ifelse{html}{\code{\link[stats]{model.frame}}}{\code{stats::model.frame}} 
+#'   in the preparation of model matrices.}
 #'
 #'   The generic function
 #'   \ifelse{html}{\code{\link[base]{summary}}}{\code{base::summary()}} can be
@@ -305,7 +332,14 @@ aldvmm <- function(formula,
                    init.lo = NULL,
                    init.hi = NULL,
                    se.fit = FALSE,
-                   level = 0.95) {
+                   model = TRUE,
+                   level = 0.95,
+                   na.action = "na.omit") {
+  
+  # Store function call
+  #--------------------
+  
+  call <- match.call()
   
   # Labels
   #-------
@@ -331,7 +365,7 @@ aldvmm <- function(formula,
   if (all(init.lo == -Inf) & all(init.hi == Inf) & 
       is.null(optim.method)) {
     # Default optimization method
-    optim.method <- "Nelder-Mead"
+    optim.method <- "BFGS"
   } else if ((!is.null(init.lo) | !is.null(init.hi))) {
     # Constrained optimization with "L-BFGS-B"
     optim.method <- "L-BFGS-B"
@@ -361,37 +395,60 @@ aldvmm <- function(formula,
   # Checks
   #-------
   
-  aldvmm.check(data = data, 
-               formula = formula, 
+  aldvmm.check(formula = formula, 
+               data = data, 
                psi = psi, 
                ncmp = ncmp, 
                dist = dist,
-               lcoef = lcoef,
-               lcpar = lcpar,
-               lcmp = lcmp,
-               init.method = init.method, 
                optim.method = optim.method, 
                optim.grad = optim.grad,
                optim.control = optim.control,
+               init.method = init.method, 
                init.est = init.est,
                init.lo = init.lo,
                init.hi = init.hi,
                se.fit = se.fit,
-               level = level)
-  
-  # Make list of design matrices
-  #-----------------------------
-  
-  mm <- aldvmm.mm(data = data,
-                  formula = formula,
-                  ncmp = ncmp,
-                  lcoef = lcoef)
+               model = model,
+               level = level,
+               na.action = na.action,
+               lcoef = lcoef,
+               lcpar = lcpar,
+               lcmp = lcmp)
   
   # Make outcome vector
   #--------------------
   
-  complete <- stats::complete.cases(data[, all.vars(formula)])
-  y <- data[complete, all.vars(formula)[1]]
+  # Convert formula to 'Formula' object
+  formula <- Formula::Formula(formula)
+  
+  # Create outcome vector
+  y <- stats::model.response(
+    stats::model.frame(formula, 
+                       data = data,
+                       na.action = na.action)
+  )
+  
+  # Make list of design matrices
+  #-----------------------------
+  
+  # Convert data to model frame
+  data <- stats::model.frame(formula, 
+                             data = data,
+                             na.action = na.action)
+  
+  # Make list of design matrices
+  mm <- aldvmm.mm(mf = data,
+                  Formula = formula,
+                  ncmp = ncmp,
+                  lcoef = lcoef)
+  
+  # Make list of model terms
+  #-------------------------
+  
+  terms <- aldvmm.tm(mf = data,
+                     Formula = formula,
+                     ncmp = ncmp,
+                     lcoef = lcoef)
   
   # Generate initial values
   #------------------------
@@ -481,15 +538,6 @@ aldvmm <- function(formula,
                       lcmp = lcmp,
                       lcpar = lcpar)
   
-  # Assess goodness of fit
-  #-----------------------
-  
-  # Note: Aldvmm.ll returns -log-likelihood
-  
-  gof <- aldvmm.gof(res = pred[["res"]],
-                    par = fit[["par"]],
-                    ll = -fit[["value"]])
-  
   # Obtain standard errors of the fit (delta method)
   #-------------------------------------------------
   
@@ -498,7 +546,6 @@ aldvmm <- function(formula,
                             yhat = pred[["yhat"]],
                             X = mm,
                             type = "fit",
-                            formula = formula,
                             cv = cov[["cv"]],
                             mse = gof[["mse"]],
                             psi = psi,
@@ -516,42 +563,52 @@ aldvmm <- function(formula,
     
   }
   
+  # Calculate degrees of freedom
+  #-----------------------------
+  
+  df.null <- length(y) - 
+    ncmp * as.integer(attr(terms[[lcoef[1]]], "intercept") > 0L) - 
+    (ncmp > 1) * as.integer(attr(terms[[lcoef[2]]], "intercept") > 0L) -
+    ncmp # standard errors lnsigma
+  
+  df.residual <- length(y) - length(fit$par)
+  
+  # Assess goodness of fit
+  #-----------------------
+  
+  # Note: Aldvmm.ll returns -log-likelihood
+  
+  gof <- aldvmm.gof(res = pred[["res"]],
+                    par = fit[["par"]],
+                    ll = -fit[["value"]])
+  
   # Collect output
   #---------------
   
-  outlist <- new_aldvmm(n = nrow(mm[[1]]),
-                        k = ncmp,
-                        dist = dist,
-                        coef = fit[["par"]],
-                        se = cov[["se"]],
-                        z = cov[["z"]],
-                        p = cov[["p"]],
-                        lower = cov[["lower"]],
-                        upper = cov[["upper"]],
-                        hessian = cov[["hessian"]],
-                        cov = cov[["cv"]],
-                        mse = gof[["mse"]],
-                        mae = gof[["mae"]],
-                        ll = gof[["ll"]],
-                        aic = gof[["aic"]],
-                        bic = gof[["bic"]],
-                        yhat = pred[["yhat"]],
-                        y = pred[["y"]],
-                        res = pred[["res"]],
-                        prob = pred[["prob"]],
-                        se.fit = pred.se[["se.fit"]],
-                        lower.fit = pred.se[["lower.fit"]],
-                        upper.fit = pred.se[["upper.fit"]],
+  outlist <- new_aldvmm(fit = fit,
+                        cov = cov,
+                        y = y,
+                        mm = mm,
+                        ncmp = ncmp,
+                        df.null = df.null,
+                        df.residual = df.residual,
+                        gof = gof,
+                        pred = pred,
+                        pred.se = pred.se,
                         init = init,
-                        formula = formula,
+                        call = call,
+                        formula = stats::formula(formula),
+                        terms = terms,
+                        data = if(model == TRUE) {data} else {NULL},
                         psi = psi,
+                        dist = dist,
                         lcoef = lcoef,
                         lcpar = lcpar,
                         lcmp = lcmp,
-                        lvar = lapply(mm, function(x) colnames(x)),
                         optim.method = optim.method,
                         init.method = init.method,
-                        level = level)
+                        level = level,
+                        na.action = attr(data, "na.action"))
   
   return(outlist)
   
