@@ -1,11 +1,9 @@
 #' Predict Method for Adjusted Limited Dependent Variable Mixture Model Fits
 #'
-#' The generic function
+#' The method \code{predict.aldvmm} for the generic function
 #' \ifelse{html}{\code{\link[stats]{predict}}}{\code{stats::predict()}} calls
-#' \ifelse{html}{\code{\link[aldvmm]{aldvmm.pred}}}{\code{aldvmm.pred()}} to
-#' predict outcomes and their standard errors in new data using
-#' \ifelse{html}{\code{\link[aldvmm]{aldvmm.pred}}}{\code{aldvmm.pred()}} and
-#' \ifelse{html}{\code{\link[aldvmm]{aldvmm.sefit}}}{\code{aldvmm.sefit()}}.
+#' \ifelse{html}{\code{\link[aldvmm]{aldvmm.pred}}}{\code{aldvmm.pred()}} and \ifelse{html}{\code{\link[aldvmm]{aldvmm.sefit}}}{\code{aldvmm.sefit()}} to
+#' predict outcomes and their standard errors in new data.
 #'
 #' @param object an object inheriting from class 'aldvmm'.
 #' @param newdata a data frame, list or environment (or object coercible to a
@@ -43,13 +41,33 @@ predict.aldvmm <- function(object,
          "\n")
   })
   
+  # Make list of empty outcome vectors including incomplete rows of newdata
+  #------------------------------------------------------------------------
+  
+  pred <- list()
+  
+  pred[["yhat"]] <- rep(NA, times = nrow(newdata))
+  names(pred[["yhat"]]) <- rownames(newdata)
+  
+  pred[["se.fit"]] <- rep(NA, times = nrow(newdata))
+  names(pred[["se.fit"]]) <- rownames(newdata)
+  
+  pred[["ll"]] <- rep(NA, times = nrow(newdata))
+  names(pred[["ll"]]) <- rownames(newdata)
+  
+  pred[["ul"]] <- rep(NA, times = nrow(newdata))
+  names(pred[["ul"]]) <- rownames(newdata)
+  
   # Make list of design matrices
   #-----------------------------
   
-  mm <- aldvmm.mm(data    = newdata,
-                  formula = object[["formula"]],
-                  ncmp    = object[["k"]],
-                  lcoef   = object[["label"]][["lcoef"]])
+  formula <- Formula::Formula(object[["formula"]])
+  newdata <- stats::model.frame(formula, data = newdata)
+  
+  mm <- aldvmm.mm(mf = newdata,
+                  Formula = formula,
+                  ncmp = object[["k"]],
+                  lcoef = object[["label"]][["lcoef"]])
   
   # Predict outcomes
   #-----------------
@@ -64,11 +82,6 @@ predict.aldvmm <- function(object,
                      lcpar = object[["label"]][["lcpar"]],
                      lcmp  = object[["label"]][["lcmp"]])
   
-  # Add missing predictions for incomplete observations in newdata
-  pred <- list()
-  pred[["yhat"]] <- rep(NA, times = nrow(newdata))
-  names(pred[["yhat"]]) <- rownames(newdata)
-  
   pred[["yhat"]][names(tmp[["yhat"]])] <- tmp[['yhat']]
   
   # Estimate standard errors of predictions and prediction intervals
@@ -81,7 +94,6 @@ predict.aldvmm <- function(object,
                         yhat    = pred[["yhat"]],
                         X       = mm,
                         type    = type,
-                        formula = object[["formula"]],
                         cv      = object[["cov"]],
                         mse     = object[["gof"]][["mse"]],
                         psi     = object[["psi"]],
@@ -92,18 +104,9 @@ predict.aldvmm <- function(object,
                         lcpar   = object[["label"]][["lcpar"]],
                         lcmp    = object[["label"]][["lcmp"]])
     
-    # Add missing standard errors and confidence bands for incomplete 
-    # observations in newdata
-    pred[["se.fit"]] <- rep(NA, times = nrow(newdata))
-    names(pred[["se.fit"]]) <- rownames(newdata)
+    # Add output to complete observations of newdata
     pred[["se.fit"]][names(tmp[["se.fit"]])] <- tmp[['se.fit']]
-    
-    pred[["ll"]] <- rep(NA,times = nrow(newdata))
-    names(pred[["ll"]]) <- rownames(newdata)
     pred[["ll"]][names(tmp[["lower.fit"]])] <- tmp[['lower.fit']]
-    
-    pred[["ul"]] <- rep(NA,times = nrow(newdata))
-    names(pred[["ul"]]) <- rownames(newdata)
     pred[["ul"]][names(tmp[["upper.fit"]])] <- tmp[['upper.fit']]
     
   }
